==> apache-sedona-1.7.1-src.tar.gz: apache-sedona-1.7.1-src/CONTRIBUTING.md <==
<!--
 Licensed to the Apache Software Foundation (ASF) under one
 or more contributor license agreements.  See the NOTICE file
 distributed with this work for additional information
 regarding copyright ownership.  The ASF licenses this file
 to you under the Apache License, Version 2.0 (the
 "License"); you may not use this file except in compliance
 with the License.  You may obtain a copy of the License at

   http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing,
 software distributed under the License is distributed on an
 "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 KIND, either express or implied.  See the License for the
 specific language governing permissions and limitations
 under the License.
 -->

# How to contribute to Apache Sedona

Welcome!  We'd love to have you contribute to Apache Sedona!

## Did you find a bug?

Create an issue with a reproducible example.  Please specify the Sedona version, Java version, code snippet, and error message.

## Did you create a PR to fix a bug?

See [here](https://sedona.apache.org/latest/community/rule/#make-a-pull-request) for instructions on how to open PRs.

We appreciate bug fixes - thank you in advance!

## Would you like to add a new feature or change existing code?

If you would like to add a feature or change existing behavior, please make sure to create an issue/JIRA ticket and get the planned work approved by the core team first!

It's always better to get aligned with the core devs before writing any code.

## Do you have questions about the source code?

Feel free to create an issue or join the [Discord](https://share.hsforms.com/1Ndql_ZigTdmLlVQc_d1o4gqga4q) with questions!

Thanks for reading and looking forward to collaborating with you!

==> apache-sedona-1.7.2-src.tar.gz: apache-sedona-1.7.2-src/CONTRIBUTING.md <==
<!--
 Licensed to the Apache Software Foundation (ASF) under one
 or more contributor license agreements.  See the NOTICE file
 distributed with this work for additional information
 regarding copyright ownership.  The ASF licenses this file
 to you under the Apache License, Version 2.0 (the
 "License"); you may not use this file except in compliance
 with the License.  You may obtain a copy of the License at

   http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing,
 software distributed under the License is distributed on an
 "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 KIND, either express or implied.  See the License for the
 specific language governing permissions and limitations
 under the License.
 -->

# How to contribute to Apache Sedona

Welcome!  We'd love to have you contribute to Apache Sedona!

## Did you find a bug?

Create an issue with a reproducible example.  Please specify the Sedona version, Java version, code snippet, and error message.

## Did you create a PR to fix a bug?

See [here](https://sedona.apache.org/latest/community/rule/#make-a-pull-request) for instructions on how to open PRs.

We appreciate bug fixes - thank you in advance!

## Would you like to add a new feature or change existing code?

If you would like to add a feature or change existing behavior, please make sure to create an issue/JIRA ticket and get the planned work approved by the core team first!

It's always better to get aligned with the core devs before writing any code.

## Do you have questions about the source code?

Feel free to create an issue or join the [Discord](https://discord.gg/9A3k5dEBsY) with questions!

Thanks for reading and looking forward to collaborating with you!
